==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPaneDragStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragStartEventArgsDetailDescriptionMetadata } from "./WebPaneDragStartEventArgsDetailDescriptionMetadata";
import { WebPaneDragStartEventArgsDescription } from "./WebPaneDragStartEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragStartEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragStartEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragStartEventArgsDescriptionMetadata.a == null) {
                WebPaneDragStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragStartEventArgsDescriptionMetadata.c(WebPaneDragStartEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragStartEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPaneDragStartEventArgsDescriptionMetadata.a);
            WebPaneDragStartEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragStartEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneDragStartEventArgsDetail");
        }
        static d(a) {
            WebPaneDragStartEventArgsDescriptionMetadata.b(a);
            a.ac("WebPaneDragStartEventArgs", () => new WebPaneDragStartEventArgsDescription());
            a.ab("WebPaneDragStartEventArgs", WebPaneDragStartEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragStartEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragStartEventArgsDescriptionMetadata, 'WebPaneDragStartEventArgsDescriptionMetadata');
    WebPaneDragStartEventArgsDescriptionMetadata.a = null;
    return WebPaneDragStartEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebPaneDragStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragStartEventArgsDetailDescriptionMetadata } from "./WebPaneDragStartEventArgsDetailDescriptionMetadata";
import { WebPaneDragStartEventArgsDescription } from "./WebPaneDragStartEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragStartEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragStartEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragStartEventArgsDescriptionMetadata.a == null) {
                WebPaneDragStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragStartEventArgsDescriptionMetadata.c(WebPaneDragStartEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragStartEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneDragStartEventArgsDescriptionMetadata.a);
            WebPaneDragStartEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragStartEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneDragStartEventArgsDetail");
        }
        static d(a) {
            WebPaneDragStartEventArgsDescriptionMetadata.b(a);
            a.ae("WebPaneDragStartEventArgs", () => new WebPaneDragStartEventArgsDescription());
            a.ad("WebPaneDragStartEventArgs", WebPaneDragStartEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragStartEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragStartEventArgsDescriptionMetadata, 'WebPaneDragStartEventArgsDescriptionMetadata');
    WebPaneDragStartEventArgsDescriptionMetadata.a = null;
    return WebPaneDragStartEventArgsDescriptionMetadata;
})();
